/* ================================================================================================================================
  Christian Thomas July 2019 adapted from Andrew Pericak, July 2016
  
  This script was created by SkyTruth to create annual NDVI Threshold Images. The script examines each county in the specified 
  study area individualluy, collects all the NDVI values within that county's borders per year, masks out urban/water areas as well 
  as mine permit areas, and sets the threshold at the mean value of the 0th - 3rd percentiles of the remaining NDVI values. The 
  script then creates a yearly image by mosaicking all those county-scale thresholds together into one image, creating a raster 
  showing each county with its unique threshold. These yearly, county-scale threshold images are then used in the mine analysis to 
  compare the NDVI threshold with the NDVI values presented in the greenest pixel composites.
-----------------------------------------------------------------------------------------------------------------------------------
	The methodology of the MTM data produced for PLOS One relied on the now deprecated Pre-Collection Landsat data. The USGS 
	Switched to the Collection format around May 2017. This change has prompted a shift to use USGS Landsat Collection 1 Tier 1 and 
	Real-Time Raw Scenes, and is reflected here. Read about the original study here: 
	https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0197758
================================================================================================================================ */

/* ------------------------------------------ IMPORT GREENEST COMPOSITE FEATURE COLLECTION ------------------------------------- */
var greenestComposites = ee.ImageCollection('users/skytruth-data/MTR/greenestPixelComposites_allBand_allIndex');

/* -------------------------------------------------- IMPORT STUDY AREA -------------------------------------------------------- */
var studyArea = ee.FeatureCollection('users/skytruth-data/Plos_MTM_Fusion_Table_Backup/plosScriptFusionTableBackup/studyArea');

var fips_codes = [21013,21019,21025,21043,21051,21053,21063,21065,21071,21089,21095,21109,21115,21119,21121,21125,
                  21127,21129,21131,21133,21135,21147,21153,21159,21165,21175,21189,21193,21195,21197,21199,21203,
                  21205,21231,21235,21237,47001,47013,47025,47035,47049,47129,47133,47137,47141,47145,47151,51027,
                  51051,51105,51167,51169,51185,51195,51720,54005,54011,54015,54019,54025,54039,54043,54045,54047,
                  54053,54055,54059,54067,54075,54079,54081,54089,54099,54101,54109];

var allCounties = ee.FeatureCollection('users/skytruth-data/Plos_MTM_Fusion_Table_Backup/plosScriptFusionTableBackup/allCounties');
var features = allCounties.filter(ee.Filter.inList('FIPS', fips_codes));

/* ----------------------------------------------------- IMPORT MASKS -----------------------------------------------------------*/
// var mask_input_60m_2017 = ee.Image('users/skytruth-data/MTR/2017_Input-Mask_TR_4326').unmask();
var mask_input_60m_2019 = ee.Image('users/skytruth-data/MTR/2019_Input-Mask_CT_4326').unmask();
// Roads, water bodies, urban areas, etc., buffered 60 m. From USCB. For whatever reason, using the 2017 mask properly requires an
// .unmask() call...

var miningPermits = ee.Image('users/andrewpericak/allMinePermits');
// All surface mining permits, buffered 1000 m. Get the link here: https://drive.google.com/file/d/0B_PTuMKVy7beSWdZUkJIS3hneW8/view

var miningPermits_noBuffer = ee.Image('users/andrewpericak/allMinePermits_noBuffer');
// All surface mining permits, without any buffer

// This excludes from the 60 m mask (mask_input_60m_2017) any areas within the the mine permit boundaries. Since the 60 m mask is
// "inversed" (i.e., 0 means keep and 1 means eventually mask), this line sets the mine permit areas (labeled as 1) to 0.

var mask_input_excludeMines = mask_input_60m_2019.where(miningPermits_noBuffer.eq(1), 0);

/* ------------------------------------------------- CREATE THRESHOLD IMAGES ----------------------------------------------------*/
// SET THE YEAR for the threshold image you want to make
var year = 1984; // 1984 - 2019
var description = "thresholds_0-3_"+year;

// This will make the threshold  by getting interval mean from 0th to 3rd percentile of NDVI values per county, for the year 
// specified above.
var yearImg = ee.Image(greenestComposites
  .filterMetadata("year", "equals", year).first())
  .select("NDVI")
  .updateMask(miningPermits_noBuffer.unmask().not())
  .updateMask(mask_input_60m_2019.not());

var reduceAll = ee.ImageCollection(features.map(function(feature){
  return yearImg.reduceRegion({
    reducer: ee.Reducer.intervalMean(0,3),
    geometry: feature.geometry(),
    scale: 30,
    maxPixels: 1e10
  }).toImage().toFloat().clip(feature);
})).mosaic();

// This exports the mosaicked percentile image, creating an image in which each county has its unique NDVI threshold value.
Export.image.toAsset({
  image: reduceAll.set({"year": year}),
  description: description,
  assetId: "users/skytruth-data/MTR/annualThresholdImages_2017-Mask/"+description,
  region: studyArea.geometry(),
  scale: 30,
  maxPixels: 1e10
});